// Farsi

jQuery.extend( jQuery.fn.pickadate.defaults, {
    monthsFull: [ 'ژانویه', 'فوریه', 'مارس', 'آوریل', 'مه', 'ژوئن', 'ژوئیه', 'اوت', 'سپتامبر', 'اکتبر', 'نوامبر', 'دسامبر'],
    monthsShort: [ 'ژانویه', 'فوریه', 'مارس', 'آوریل', 'مه', 'ژوئن', 'ژوئیه', 'اوت', 'سپتامبر', 'اکتبر', 'نوامبر', 'دسامبر' ],
    weekdaysFull: [ 'یکشنبه', 'دوشنبه', 'سه شنبه', 'چهارشنبه', 'پنجشنبه', 'جمعه', 'شنبه' ],
    weekdaysShort: [ 'یکشنبه', 'دوشنبه', 'سه شنبه', 'چهارشنبه', 'پنجشنبه', 'جمعه', 'شنبه' ],
    today: 'امروز',
    clear: 'پاک کردن',
    close: 'بستن',
    format: 'yyyy mmmm dd',
    formatSubmit: 'yyyy/mm/dd',
    labelMonthNext: 'ماه بعدی',
	labelMonthPrev: 'ماه قبلی'
});

jQuery.extend( jQuery.fn.pickatime.defaults, {
    clear: 'پاک کردن'
});
