<div class="ui inverted vertical footer segment">
    <div class="ui container">
        <div class="ui stackable inverted divided equal height stackable grid">
            <div class="four wide column">
                <h4 class="ui inverted header">Contact</h4>
                <div class="ui inverted link list">
                    <a href="mailto:info@cosmicdb.com.au" class="item"><i class="envelope icon"></i> Email - info@cosmicdb.com.au</a>
                    <a href="tel:+61417889720" class="item"><i class="phone icon"></i> Phone - 0417 889 720</a>
                </div>
            </div>
            <div class="four wide column">
                <h4 class="ui inverted header">Related Links</h4>
                <div class="ui inverted link list">
                    <a href="https://bitbucket.org/davidbradleycole/cosmicdb/src/master/" target="_blank" class="item"><i class="bitbucket icon"></i> CosmicDB Admin Git Repo</a>
                    <a href="https://pypi.org/project/cosmicdb/" target="_blank" class="item"><i class="python icon"></i> CosmicDB Admin Python Package</a>
                    <a href="https://bitbucket.org/davidbradleycole/cosmicdbsemantic/src/master/" target="_blank" class="item"><i class="bitbucket icon"></i> CosmicDB Semantic Git Repo</a>
                    <a href="https://pypi.org/project/cosmicdbsemantic/" target="_blank" class="item"><i class="python icon"></i> CosmicDB Semantic Python Package</a>
                </div>
            </div>
            <div class="eight wide column">
                <h4 class="ui inverted header"><a href="{% url 'home' %}">CosmicDB</a></h4>
                <p><i class="copyright outline icon"></i> Copyright 2018</p>
            </div>
        </div>
    </div>
</div>
