{% extends 'cosmicdb/base_form.html' %}

{% load crispy_forms_tags %}

{% block form_content %}
    <form class="ui form{% if form.non_field_errors %} error{% endif %}" enctype="multipart/form-data" method="post">
        {{ block.super }}
        {% for inline in inlines %}
            {% crispy inline formset_helper %}
        {% endfor %}
        {% block submit_row %}
            <input name="save" value="Save" class="btn btn-primary ui submit button large primary" id="submit-id-save" type="submit">
            {% if delete_button %}<input name="delete" value="Delete" class="btn ui button large red" id="button-id-delete" onclick="window.location.href = 'delete';" type="button">{% endif %}
        {% endblock %}
    </form>
{% endblock %}