{% extends 'cosmicdb/base.html' %}

{% load static cosmic_tags crispy_forms_tags sitetree %}

{% block style %}

    {{ block.super }}

{% endblock %}

{% block content %}
    <h2>{% sitetree_page_title from "cosmicdb" %}</h2>
    <div class="ui secondary inverted segment">
        <p>Your password has changed.</p>
    </div>
{% endblock %}
