{% extends 'cosmicdb/base_form.html' %}

{% block form_content %}
{% endblock %}

{% block form_footer %}
    <div class="ui secondary inverted segment">
        <p>Extend this dashboard by extending the cosmicdb/dashboard.html template.</p>
    </div>
{% endblock %}
