{% extends 'cosmicdb/base.html' %}

{% load sitetree %}
{% load render_table from django_tables2 %}

{% block content %}
    <h2 class="ui header">{% sitetree_page_title from "cosmicdb" %}</h2>
    {% block before_table %}
        {% if add_url %}<a class="ui button primary" href="{{ add_url }}"><i class="plus icon"></i> {% if add_label %}{{ add_label }}{% else %}Add{% endif %}</a>{% endif %}
    {% endblock %}
    {% render_table table %}
    {% block after_table %}
    {% endblock %}
{% endblock %}